@@ -11,18 +11,15 @@ const char argv0[] = "dumpelf";
 #include "paxinc.h"
 
 /* prototypes */
-static void dumpelf(const char *filename, size_t file_cnt);
-static void dump_ehdr(elfobj *elf, const void *ehdr);
-static void dump_phdr(elfobj *elf, const void *phdr, size_t phdr_cnt);
-static void dump_shdr(elfobj *elf, const void *shdr, size_t shdr_cnt, const char *section_name);
-static void dump_dyn(elfobj *elf, const void *dyn, size_t dyn_cnt);
+static void dump_ehdr(const elfobj *elf, const void *ehdr);
+static void dump_phdr(const elfobj *elf, const void *phdr, size_t phdr_cnt);
+static void dump_shdr(const elfobj *elf, const void *shdr, size_t shdr_cnt, const char *section_name);
+static void dump_dyn(const elfobj *elf, const void *dyn, size_t dyn_cnt);
 #if 0
-static void dump_sym(elfobj *elf, const void *sym);
-static void dump_rel(elfobj *elf, const void *rel);
-static void dump_rela(elfobj *elf, const void *rela);
+static void dump_sym(const elfobj *elf, const void *sym);
+static void dump_rel(const elfobj *elf, const void *rel);
+static void dump_rela(const elfobj *elf, const void *rela);
 #endif
-static void usage(int status);
-static void parseargs(int argc, char *argv[]);
 
 /* variables to control behavior */
 static char be_verbose = 0;
@@ -31,15 +28,10 @@ static char be_verbose = 0;
 static const void *phdr_dynamic_void;
 
 /* dump all internal elf info */
-static void dumpelf(const char *filename, size_t file_cnt)
+static void dumpelf(const elfobj *elf, size_t file_cnt)
 {
-	elfobj *elf;
 	size_t i, b;
 
-	/* verify this is real ELF */
-	if ((elf = readelf(filename)) == NULL)
-		return;
-
 	phdr_dynamic_void = NULL;
 
 	printf("#include <elf.h>\n");
@@ -50,7 +42,7 @@ static void dumpelf(const char *filename, size_t file_cnt)
 		" * ELF dump of '%s'\n"
 		" *     %ji (0x%jX) bytes\n"
 		" */\n\n",
-		filename, elf->len, elf->len);
+		elf->filename, elf->len, elf->len);
 
 	/* setup the struct to namespace this elf */
 #define MAKE_STRUCT(B) \
@@ -148,12 +140,23 @@ static void dumpelf(const char *filename, size_t file_cnt)
 		printf(" /* no dynamic tags ! */ ");
 	}
 	printf("};\n");
+}
+
+static void dumpelf_file(const char *filename, size_t file_cnt)
+{
+	elfobj *elf = readelf(filename);
+
+	/* verify this is real ELF */
+	if (elf == NULL)
+		return;
+
+	dumpelf(elf, file_cnt);
 
 	/* get out of here */
 	unreadelf(elf);
 }
 
-static void dump_ehdr(elfobj *elf, const void *ehdr_void)
+static void dump_ehdr(const elfobj *elf, const void *ehdr_void)
 {
 #define DUMP_EHDR(B) \
 	if (elf->elf_class == ELFCLASS ## B) { \
@@ -203,7 +206,7 @@ static void dump_ehdr(elfobj *elf, const void *ehdr_void)
 	DUMP_EHDR(64)
 }
 
-static void dump_notes(elfobj *elf, size_t B, const void *memory, const void *memory_end)
+static void dump_notes(const elfobj *elf, size_t B, const void *memory, const void *memory_end)
 {
 	/* While normally we'd worry about Elf32_Nhdr vs Elf64_Nhdr, in the ELF
 	 * world, the two structs are exactly the same.  So avoid ugly CPP.
@@ -294,7 +297,7 @@ static const char *dump_p_flags(uint32_t type, uint32_t flags)
 
 	return buf + 3;
 }
-static void dump_phdr(elfobj *elf, const void *phdr_void, size_t phdr_cnt)
+static void dump_phdr(const elfobj *elf, const void *phdr_void, size_t phdr_cnt)
 {
 #define DUMP_PHDR(B) \
 	if (elf->elf_class == ELFCLASS ## B) { \
@@ -351,7 +354,7 @@ static const char *timestamp(uint64_t stamp)
 	return buf;
 }
 
-static void dump_shdr(elfobj *elf, const void *shdr_void, size_t shdr_cnt, const char *section_name)
+static void dump_shdr(const elfobj *elf, const void *shdr_void, size_t shdr_cnt, const char *section_name)
 {
 	size_t i;
 
@@ -483,7 +486,7 @@ static void dump_shdr(elfobj *elf, const void *shdr_void, size_t shdr_cnt, const
 	DUMP_SHDR(64)
 }
 
-static void dump_dyn(elfobj *elf, const void *dyn_void, size_t dyn_cnt)
+static void dump_dyn(const elfobj *elf, const void *dyn_void, size_t dyn_cnt)
 {
 #define DUMP_DYN(B) \
 	if (elf->elf_class == ELFCLASS ## B) { \
@@ -570,10 +573,29 @@ static void parseargs(int argc, char *argv[])
 	size_t file_cnt = 0;
 
 	while (optind < argc)
-		dumpelf(argv[optind++], file_cnt++);
+		dumpelf_file(argv[optind++], file_cnt++);
 	}
 }
 
+#if PAX_UTILS_LIBFUZZ
+int LLVMFuzzerInitialize(int *argc, char ***argv)
+{
+	(void)argc;
+	(void)argv;
+	(void)parseargs;
+	security_init(false);
+	return 0;
+}
+
+int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
+{
+	elfobj *elf = readelf_buffer("libFuzzer", data, size);
+	if (elf == NULL)
+		return 0;
+	dumpelf(elf, 0);
+	return 0;
+}
+#else
 int main(int argc, char *argv[])
 {
 	security_init(false);
@@ -582,3 +604,4 @@ int main(int argc, char *argv[])
 	parseargs(argc, argv);
 	return EXIT_SUCCESS;
 }
+#endif
